@@ -128,7 +128,7 @@ static int sbc_read_capacity(int host_no, struct scsi_cmd *cmd)
 	unsigned char key = ILLEGAL_REQUEST;
 	uint16_t asc = ASC_LUN_NOT_SUPPORTED;
 
-	if (!(scb[8] & 0x1) & (scb[2] | scb[3] | scb[4] | scb[5])) {
+	if (!(scb[8] & 0x1) && (scb[2] | scb[3] | scb[4] | scb[5])) {
 		asc = ASC_INVALID_FIELD_IN_CDB;
 		goto sense;
 	}
@@ -243,11 +243,6 @@ static int sbc_lu_init(struct scsi_lu *lu)
 	add_mode_page(lu, "0:0:0");
 	/* Disconnect page */
 	add_mode_page(lu, "2:0:14:0x80:0x80:0:0xa:0:0:0:0:0:0:0:0:0:0");
-	/* Format page */
-	add_mode_page(lu, "3:0:22:0:0:0:0:0:0:0:0:1:0:2:0:0:0:0:0:0:0:0:13:0:0");
-	/* GEO page */
-	add_mode_page(lu, "4:0:22:0:0:0:0x40:0:0:0:0:0:"
-		      "0:0:0:0:0:0:0:0:0:0x3a:0x98:0:0");
 	/* Caching Page */
 	add_mode_page(lu, "8:0:18:0x14:0:0xff:0xff:0:0:"
 		      "0xff:0xff:0xff:0xff:0x80:0x14:0:0:0:0:0:0");
